# PEP-484 Stubs for django-filter ::: Beta

[![CI](https://github.com/DavisRayM/django-filter-stubs/actions/workflows/ci.yml/badge.svg)](https://github.com/DavisRayM/django-filter-stubs/actions/workflows/ci.yml)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)

This package contains type subs to provide more precise static types for Django Filters.

## Installation

```bash
pip install django-filter-stubs
```
